@@ -71,7 +71,7 @@ class TestSudoku:
         assert (sudoku_fixture.possible_numbers == expected).all()
 
     def test_check_solvable__true(self, generator):
-        generator.generate_grid(50)
+        generator.generate_grid(seed=50)
         generator.sudoku.grid[0, 1] = 0
         assert generator.sudoku.check_solvable()
 
